pilas.interprete

Package pilas :: Module interprete |
[hide private]
[frames] | no frames]

# Module interprete

source code

Classes | [hide private]
| VentanaInterprete

Functions | [hide private]
main(parent=None, do_raise=False) | source code

Variables | [hide private]
| __package__ = ``'``pilas``'``
| __warningregistry__ = ``{``(``'``Not importing directory \'/Users/hugo``...``
| e = `ImportError('No module named PyQt4.QtGui',)`

Variables Details | [hide private]

  ### __warningregistry__ Value:
      {('Not importing directory \'/Users/hugoruscitti/proyectos/pilas.git/l
      anas\': missing __init__.py',
        <type 'exceptions.ImportWarning'>,
        17): True,
       ('Not importing directory \'lanas\': missing __init__.py',
        <type 'exceptions.ImportWarning'>,
        17): True}